@@ -10,7 +10,7 @@
 #include "config.h"
 #endif
 
-#include <kmsgbox.h>
+#include <qmessagebox.h>
 #include <klocale.h>
 
 extern KLocale *locale;
@@ -19,19 +19,20 @@ extern KLocale *locale;
 
 void showAbout(void)
  {
-  KMsgBox *kmsg;
+  QMessageBox *qmsg;
   char abouttext[2048];
 
   strcpy(abouttext,KREATECD_VERSION "\n\n");
   strcat(abouttext,
   locale->translate(
-  "1998 by Alexander Feigl\n\n"
+  "1998-1999 by Alexander Feigl\n\n"
   "Alexander Feigl\n"
   "Burachstrasse 51\n"
   "88250 Weingarten\n\n"
   "Alexander.Feigl@gmx.de\n\n"
   "This software is distributed under the\nGNU Public License! Hope youll enjoy it!\n"));
  
-  kmsg=new KMsgBox(0,KREATECD_VERSION,abouttext,KMsgBox::INFORMATION,locale->translate("Great!"));
-  kmsg->show();
+  qmsg=new QMessageBox(KREATECD_VERSION,abouttext,QMessageBox::Information,QMessageBox::Ok,0,0);
+  qmsg->setButtonText(QMessageBox::Ok,locale->translate("Great!"));
+  qmsg->show();
  }
