@@ -191,22 +191,6 @@ int AudioFile::fillSampleBuffer(void)
   return(0);
  }
 
-inline int AudioFile::readSample(long int *sample)
- {
-  if (AudioCached<=AudioPointer)
-   {
-    if (!fillSampleBuffer()) return(0);
-   }
-  *sample=AudioBuffer[AudioPointer++];
-  return(1);
- }
-
-inline int AudioFile::readString(char *mstring,int length)
- {
-  if (read(AudioFD,mstring,length)!=length) return(0);
-  return(1);
- }
-
 AudioFile::AudioFile(void)
  {
   AudioFD=-1;
@@ -396,38 +380,6 @@ int AudioFile::flushCDDABuffer(void)
  }
 
 
-inline int AudioFile::writeCDDASample(float msample)
- {
-
-  long int xsample;
-
-  xsample=(long int )msample;
-
-  if (ImageContent>=Write_Cachesize)
-   {
-    if (!flushCDDABuffer()) return(0);
-   }
-
-  if (xsample>32767) xsample=32767;
-  if (xsample<-32768) xsample=-32768;
-
-  if (DisableSwap)
-   {
-    *(short int *) (ImageBuffer+2*ImageContent)=xsample;
-    ++ImageContent;
-    return(1);
-   }
-
-#ifdef WORDS_BIGENDIAN
-  *(short int *) (ImageBuffer+2*ImageContent)=xsample;
-#else
-  ImageBuffer[2*ImageContent]= (xsample>>8) & 0xff;
-  ImageBuffer[2*ImageContent+1]= xsample & 0xff;
-#endif
-  ++ImageContent;
-  return(1);
- }
-
 int AudioFile::openWrite(const char *filename)
  {
   closeWrite();
@@ -652,7 +604,7 @@ void AudioFile::stopAudio(void)
   if (AudioTimer) delete (AudioTimer);
   AudioTimer=0;
  }
-void AudioFile::playAudio(long int position=-1)
+void AudioFile::playAudio(long int position)
  {
   if (AudioFork) return;
 
@@ -1153,7 +1105,7 @@ int AudioFile::buildImageFork(const char *fn,int playmode)
     samplesleft=588-(sampleswritten%588);
    }
 
-  if (sampleswritten<(44100*4))
+  if ( (!playmode) && (sampleswritten<(44100*4)))
    {
     samplesleft=(44100*4)-sampleswritten;
    }
