@@ -40,7 +40,7 @@ class AudioOptions : public QWidget
   private:
     class CDTrack     *ThisTrack;
     class AudioFile   *ThisAudio;
-    class KSlider     *PlaySlider;
+    class QSlider     *PlaySlider;
     class QSlider     *BalanceSlider;
     class QSlider     *VolumeSlider;
 
