@@ -26,15 +26,19 @@ class ConfPath : public QWidget
          void applySettings(void);
          void okButton(void);
          void cancelButton(void);
+         void changeParanoia(void);
+         void changeCdrecord(void);
+         void changeMkisofs(void);
+         void changeTemp(void);
 
   private:
     static int  searchPath(const char *program,char *path=0);
 
-    class KLined   *ParanoiaPath;
-    class KLined   *IsofsPath;
-    class KLined   *CdrecordPath;
-    class KLined   *TemporaryPath;
-  
+    class QLineEdit   *ParanoiaPath;
+    class QLineEdit   *IsofsPath;
+    class QLineEdit   *CdrecordPath;
+    class QLineEdit   *TemporaryPath;
+
     class QLabel   *ParanoiaLabel;
     class QLabel   *IsofsLabel;
     class QLabel   *CdrecordLabel;
@@ -43,8 +47,6 @@ class ConfPath : public QWidget
     class QPushButton  *okbutton;
     class QPushButton  *applybutton;
     class QPushButton  *cancelbutton;
-
-
  };
 
 
