@@ -33,10 +33,8 @@ class ConfSCSI : public QWidget
 
          void updateWriterButtons(void);
          void updateCdromButtons(void);
-         void increaseWriterHost(void);
-         void decreaseWriterHost(void);
-         void increaseCdromHost(void);
-         void decreaseCdromHost(void);
+         void changedWriterHost(int host);
+         void changedCdromHost(int host);
 
   private:
 
@@ -46,8 +44,8 @@ class ConfSCSI : public QWidget
     class QPushButton  *applybutton;
     class QPushButton  *cancelbutton;
 
-    class KNumericSpinBox   *writerhostspin;
-    class KNumericSpinBox   *cdromhostspin;
+    class QSpinBox   *writerhostspin;
+    class QSpinBox   *cdromhostspin;
 
     class DriveAccess  *SCSIBus;
 
