@@ -15,10 +15,10 @@
 int readiso(int argc,char **argv);
 
 #include <qstring.h>
+#include <qmessagebox.h>
 
 #include <kprocess.h>
 #include <kapp.h>
-#include <kmsgbox.h>
 #include <kconfig.h>
 #include <klocale.h>
 
@@ -131,16 +131,20 @@ void DriveAccess::getScanBus(KProcess *,char *buffer,int bufflen)
         long int unit;
         char dummy[40];
         cptr=linebuffer;
-        while ( (*cptr==' ') || (*cptr==9) ) 
+        do
          {
-          ++cptr;
-         }
-        unit=strtol(cptr,&dptr,10);
-        if (cptr==dptr) goto ignline;
-        cptr=dptr;
+          if (*cptr==',') ++cptr;
+          while ( (*cptr==' ') || (*cptr==9) )
+           {
+            ++cptr;
+           }
+          unit=strtol(cptr,&dptr,10);
+          if (cptr==dptr) goto ignline;
+          cptr=dptr;
+         } while ( (*cptr==',') || (*cptr==' ') || (*cptr==9));
+        if (*(cptr++)!=')') goto ignline;
         unit=unit%100;
         if ( (unit<0) || (unit>(MAX_SCSI_UNITS)) ) goto ignline;
-        if (*(cptr++)!=')') goto ignline; 
         if (current_scsibus==-1) goto ignline;
         if (!copyQuotedString(&cptr,scsimanuf[current_scsibus][unit])) goto ignline;
         if (!copyQuotedString(&cptr,scsiprod[current_scsibus][unit])) goto ignline;
@@ -331,18 +335,26 @@ int DriveAccess::paranoiaTrack(int track,char *filename)
   paranoiafrom=0;
   paranoiato=999999;
 
+#ifndef STRICT_PERMISSIONS
   getRootRights();
+#endif
   cdrproc->start(KProcess::NotifyOnExit,KProcess::Stderr);
+#ifndef STRICT_PERMISSIONS
   dropRootRights();
-
+#endif
   retval=paranoiaprogress->exec();  // 1=ripping was OK  -1=abort -2=ripping error  0=window hard closed
+#ifndef STRICT_PERMISSIONS
+  getRootRights();
+  chown(filename,getuid(),getgid());
+  dropRootRights();
+#endif
   if (retval!=1) remove(filename);
   if (retval==-2)
    {
 #if QT_VERSION >= 200
-    KMsgBox::message(0,QString::null,locale->translate("Unable to read audio track!"),KMsgBox::EXCLAMATION);
+    QMessageBox::critical(0,QString::null,locale->translate("Unable to read audio track!"));
 #else
-    KMsgBox::message(0,0,locale->translate("Unable to read audio track!"),KMsgBox::EXCLAMATION);
+    QMessageBox::critical(0,0,locale->translate("Unable to read audio track!"));
 #endif
    }
   
@@ -461,47 +473,55 @@ int DriveAccess::readDataTrack(int track,char *filename,long int lba_start,long
 
   ripflag=-2;
 
+#ifndef STRICT_PERMISSIONS
   getRootRights();
+#endif
   IsoFork->start(KProcess::NotifyOnExit,KProcess::All);
+#ifndef STRICT_PERMISSIONS
   dropRootRights();
-
+#endif
   retval=isoprogress->exec();  // 1=ripping was OK  -1=abort 0=winclose
                                // -2=unexpected process term -3= DevError
                                // -4=Memory -5=Read -6=Write
+#ifndef STRICT_PERMISSIONS
+  getRootRights();
+  chown(filename,getuid(),getgid());
+  dropRootRights();
+#endif
   if (retval!=1) remove(filename);
   switch (retval)
    {
 #if QT_VERSION >= 200
     case -2:
-      KMsgBox::message(0,QString::null,locale->translate("Reading process died!"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,QString::null,locale->translate("Reading process died!"));
       break;
     case -3:
-      KMsgBox::message(0,QString::null,locale->translate("Cannot access the drive! (no disc?)"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,QString::null,locale->translate("Cannot access the drive! (no disc?)"));
       break;
     case -4:
-      KMsgBox::message(0,QString::null,locale->translate("Cannot get buffer memory!"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,QString::null,locale->translate("Cannot get buffer memory!"));
       break;
     case -5:
-      KMsgBox::message(0,QString::null,locale->translate("CDROM read error occured!"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,QString::null,locale->translate("CDROM read error occured!"));
       break;
     case -6:
-      KMsgBox::message(0,QString::null,locale->translate("Image file write error! (harddisk full?)"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,QString::null,locale->translate("Image file write error! (harddisk full?)"));
       break;
 #else
     case -2:
-      KMsgBox::message(0,0,locale->translate("Reading process died!"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,0,locale->translate("Reading process died!"));
       break;
     case -3:
-      KMsgBox::message(0,0,locale->translate("Cannot access the drive! (no disc?)"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,0,locale->translate("Cannot access the drive! (no disc?)"));
       break;
     case -4:
-      KMsgBox::message(0,0,locale->translate("Cannot get buffer memory!"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,0,locale->translate("Cannot get buffer memory!"));
       break;
     case -5:
-      KMsgBox::message(0,0,locale->translate("CDROM read error occured!"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,0,locale->translate("CDROM read error occured!"));
       break;
     case -6:
-      KMsgBox::message(0,0,locale->translate("Image file write error! (harddisk full?)"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,0,locale->translate("Image file write error! (harddisk full?)"));
       break;
 #endif
    }
@@ -561,36 +581,35 @@ void DriveAccess::getISO(KProcess *,char *buffer,int bufflen)
         int retval;
         char rerrmsg[128];
         char rchar;
-        KMsgBox *request;
         xptr=linebuffer+6;
         while ( (*xptr==' ') && (*xptr!='\0') ) ++xptr;
         if (*xptr=='\0') goto ignLine;
         lba=strtol(xptr,0,10);
         sprintf(rerrmsg,locale->translate("CD read error at block %ld!\n"),lba);
 #if QT_VERSION >= 200
-        request=new KMsgBox(0,QString::null,rerrmsg,KMsgBox::QUESTION,
+        retval=QMessageBox::information(0,QString::null,rerrmsg,
              locale->translate("Retry"),
              locale->translate("Ignore"),
-             locale->translate("Pad with 0"),
-             locale->translate("Cancel"));
+             locale->translate("Pad with 0")
+             //FIXME : only 3 buttons   ,locale->translate("Cancel")
+            );
 #else
-        request=new KMsgBox(0,0,rerrmsg,KMsgBox::QUESTION,
+        retval=QMessageBox::information(0,0,rerrmsg,
              locale->translate("Retry"),
              locale->translate("Ignore"),
-             locale->translate("Pad with 0"),
-             locale->translate("Cancel"));
+             locale->translate("Pad with 0")
+             //FIXME : only 3 buttons   ,locale->translate("Cancel")
+           );
 #endif
-        retval=request->exec();
-        delete request;
         switch (retval)
          {
-          case 1:
+          case 0:
             rchar='R';
             break;
-          case 2:
+          case 1:
             rchar='I';
             break;
-          case 3:
+          case 2:
             rchar='P';
             break;
           default:
@@ -702,9 +721,9 @@ int DriveAccess::callRecord(int ntrack,CDTrack **track,int simmode,int speed,Fix
      {
       delete (cdrproc);
 #if QT_VERSION >= 200
-      KMsgBox::message(0,QString::null,locale->translate("Image file not found!"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,QString::null,locale->translate("Image file not found!"));
 #else
-      KMsgBox::message(0,0,locale->translate("Image file not found!"),KMsgBox::EXCLAMATION);
+      QMessageBox::critical(0,0,locale->translate("Image file not found!"));
 #endif
       return(0);
      }
@@ -795,23 +814,23 @@ int DriveAccess::callRecord(int ntrack,CDTrack **track,int simmode,int speed,Fix
      {
 #if QT_VERSION >= 200
       case 10000:
-        KMsgBox::message(0,QString::null,locale->translate("Cannot access the drive! (no disc?)"),KMsgBox::EXCLAMATION);
+        QMessageBox::critical(0,QString::null,locale->translate("Cannot access the drive! (no disc?)"));
         break;
       case 10001:
-        KMsgBox::message(0,QString::null,locale->translate("Cannot open a new session!"),KMsgBox::EXCLAMATION);
+        QMessageBox::critical(0,QString::null,locale->translate("Cannot open a new session!"));
         break;
       default:
-        KMsgBox::message(0,QString::null,locale->translate("Unrecognized error while writing CD-R!!!"),KMsgBox::EXCLAMATION);
+        QMessageBox::critical(0,QString::null,locale->translate("Unrecognized error while writing CD-R!!!"));
         break;
 #else
       case 10000:
-        KMsgBox::message(0,0,locale->translate("Cannot access the drive! (no disc?)"),KMsgBox::EXCLAMATION);
+        QMessageBox::critical(0,0,locale->translate("Cannot access the drive! (no disc?)"));
         break;
       case 10001:
-        KMsgBox::message(0,0,locale->translate("Cannot open a new session!"),KMsgBox::EXCLAMATION);
+        QMessageBox::critical(0,0,locale->translate("Cannot open a new session!"));
         break;
       default:
-        KMsgBox::message(0,0,locale->translate("Unrecognized error while writing CD-R!!!"),KMsgBox::EXCLAMATION);
+        QMessageBox::critical(0,0,locale->translate("Unrecognized error while writing CD-R!!!"));
         break;
 #endif
      }
@@ -833,14 +852,13 @@ int DriveAccess::callRecord(int ntrack,CDTrack **track,int simmode,int speed,Fix
 
   if ( (retval!=1) || (getCapacity))
    {
+    // workaround : open close writer device to unlock tray
     FILE *xfile;
     QString qs;
     config->setGroup("SCSI");
     qs=config->readEntry("SCSIWriterDevice","/dev/null");
-    getRootRights();
     xfile=fopen(qs.data(),"rb");
     if (xfile!=0) fclose(xfile);
-    dropRootRights();
    }
 
   if (retval!=1) return(0);
@@ -887,10 +905,15 @@ void DriveAccess::getCdrecord(KProcess *,char *buffer,int bufflen)
         if (*xptr==0) goto ignLine;
         blocksRemain=strtoul(xptr,&yptr,10);
         if (xptr==yptr) goto ignLine;
+        goto doneLine;
+       }
+      if (strncmp("Starting to write CD",linebuffer,20)==0)
+       {
         if (getCapacity)
          {
           burnstate=99999;
-          cdrproc->kill(SIGHUP);
+          usleep(1500);  // make sure cdrecord is interruptible
+          cdrproc->kill(SIGINT);
          }
         goto doneLine;
        }
