@@ -19,6 +19,7 @@ class ISOFile
 
 
     ISOFile(ISOType type,class QString *name,class QString *reference=0);
+    ISOFile(const ISOFile &object);
     ~ISOFile(void);
 
     void addObject(class ISOFile *object);
@@ -31,6 +32,7 @@ class ISOFile
 
     bool createTree(const char *prefix);
     bool deleteTree(const char *prefix);
+    ISOFile *getParent(void);
 
   private:
 
