@@ -10,6 +10,7 @@
 
 class FileTree;
 class ISOImage;
+class ISOFile;
 class QPushButton;
 
 
@@ -29,7 +30,8 @@ class ISOWindow : public QWidget
          void addFile(void);
          void createDir(void);
          void deleteObject(void);
-
+         void cancelPressed(void);
+         
   private:
          FileTree    *sourceTree;
          FileTree    *isoTree;
@@ -39,5 +41,6 @@ class ISOWindow : public QWidget
 
 
          ISOImage *isoImage;
+         ISOFile  *backupTree;
  };
 
