@@ -22,7 +22,11 @@ LineDialog::LineDialog( QWidget *parent, const char *name,const char *startstrin
 
   qlay=new QVBoxLayout(this);
 
+#if QT_VERSION >= 200
+  EditWidget=new KLineEdit(this,0);
+#else
   EditWidget=new KLined(this,0);
+#endif
   EditWidget->setText(startstring);
    {
     QSize qsiz;
