@@ -10,8 +10,6 @@
 #include <qdialog.h>
 #include <qstring.h>
 
-class KLined;
-
 class LineDialog : public QDialog
  {
   Q_OBJECT;
@@ -26,7 +24,11 @@ class LineDialog : public QDialog
     void leaveDialog(void);
 
   private:
-    KLined *EditWidget;
+#if QT_VERSION >= 200
+    class KLineEdit *EditWidget;
+#else
+    class KLined *EditWidget;
+#endif
  };
 
 
