@@ -13,6 +13,7 @@
 #include "ConfPath.h"
 #include "WriteDialog.h"
 #include "AudioFile.h"
+#include "IsoOptions.h"
 
 #include <qwidget.h>
 #include <qpushbutton.h>
@@ -20,14 +21,14 @@
 #include <qkeycode.h>
 #include <qpopupmenu.h>
 #include <qlayout.h>
-
+#include <qmessagebox.h>
+#include <qlabel.h>
 
 #include <kmenubar.h>
 #include <kconfig.h>
 #include <kapp.h>
 #include <klocale.h>
 #include <kfiledialog.h>
-#include <kmsgbox.h>
 
 
 
@@ -85,6 +86,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
   TrackEdit=0;
   SCSIWindow=0;
   PathWindow=0;
+  ISOWindow=0;
   ProjectPath[0]=0;
 
   CurrentTrack=-1;
@@ -114,14 +116,16 @@ MainWindow::MainWindow(QWidget *parent, const char *name):QWidget(parent,name)
   MWMenu->insertItem(locale->translate("File"),filemenu);
   QPopupMenu *toolsmenu=new QPopupMenu;
   toolsmenu->insertItem(locale->translate("&Copy CDROM ..."),this,SLOT(setupCopy()));
-  toolsmenu->insertSeparator();
-  toolsmenu->insertItem(locale->translate("Normalize to maximum"),this,SLOT(normalizeMax()));
-  toolsmenu->insertItem(locale->translate("Normalize all to same"),this,SLOT(normalizeAllSame()));
+  QPopupMenu *audiomenu=new QPopupMenu;
+  audiomenu->insertItem(locale->translate("Normalize to maximum"),this,SLOT(normalizeMax()));
+  audiomenu->insertItem(locale->translate("Normalize all to same"),this,SLOT(normalizeAllSame()));
+  toolsmenu->insertItem(locale->translate("Audio"),audiomenu);
 
   MWMenu->insertItem(locale->translate("&Tools"),toolsmenu);
   QPopupMenu *configmenu=new QPopupMenu;
   configmenu->insertItem(locale->translate("SCSI ..."),this,SLOT(configSCSI()));
   configmenu->insertItem(locale->translate("Paths ..."),this,SLOT(configPath()));
+  configmenu->insertItem(locale->translate("ISO 9660 ..."),this,SLOT(configISO()));
   MWMenu->insertItem(locale->translate("Configure"),configmenu);
   MWMenu->insertSeparator();
   QPopupMenu *helpmenu=new QPopupMenu;
@@ -455,6 +459,12 @@ void MainWindow::notifyClosePathWin(void)
   PathWindow=0;
  }
 
+void MainWindow::notifyCloseISOWin(void)
+ {
+  delete ISOWindow;
+  ISOWindow=0;
+ }
+
 void MainWindow::menuMoved()
  {
   resizeEvent(0);
@@ -534,6 +544,14 @@ void MainWindow::configPath()
 
  }
 
+void MainWindow::configISO()
+ {
+  if (ISOWindow==0) ISOWindow=new ISOOptions(0,"path window");
+  ISOWindow->show();
+  connect(ISOWindow,SIGNAL(closed()),this,SLOT(notifyCloseISOWin()));
+
+ }
+
 
 void MainWindow::saveSession()
  {
@@ -606,9 +624,9 @@ void MainWindow::writeCD()
         updateTrackSum();
         CurrentTrack=t;
 #if QT_VERSION >= 200
-        KMsgBox::message(0,QString::null,locale->translate("Cannot create image files!"),KMsgBox::EXCLAMATION);
+        QMessageBox::critical(0,QString::null,locale->translate("Cannot create image files!"));
 #else
-        KMsgBox::message(0,0,locale->translate("Cannot create image files!"),KMsgBox::EXCLAMATION);
+        QMessageBox::critical(0,0,locale->translate("Cannot create image files!"));
 #endif
         return;
        }
@@ -625,9 +643,9 @@ void MainWindow::writeCD()
   if (tracks==0)
     {
 #if QT_VERSION >= 200
-     KMsgBox::message(0,QString::null,locale->translate("Nothing to write on CD!"),KMsgBox::EXCLAMATION);
+     QMessageBox::warning(0,QString::null,locale->translate("Nothing to write on CD!"));
 #else
-     KMsgBox::message(0,0,locale->translate("Nothing to write on CD!"),KMsgBox::EXCLAMATION);
+     QMessageBox::warning(0,0,locale->translate("Nothing to write on CD!"));
 #endif
      return;
     }
